guix-patches
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[bug#27754] [PATCH] vm: Increase disk size overhead estimate.


From: Tobias Geerinckx-Rice
Subject: [bug#27754] [PATCH] vm: Increase disk size overhead estimate.
Date: Tue, 18 Jul 2017 16:34:16 +0200

* gnu/build/vm.scm (estimated-partition-size): Add 25% to the graph size.
---

Guix,

Add a conservative 5% to the disk size overhead estimate. It's enough to
make ‘guix system disk-image gnu/system/install.scm’ work again for me.

Kind regards,

T

 gnu/build/vm.scm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gnu/build/vm.scm b/gnu/build/vm.scm
index 086f38ade..14bd7851f 100644
--- a/gnu/build/vm.scm
+++ b/gnu/build/vm.scm
@@ -157,8 +157,8 @@ the #:references-graphs parameter of 'derivation'."
 (define (estimated-partition-size graphs)
   "Return the estimated size of a partition that can store the store items
 given by GRAPHS, a list of file names produced by #:references-graphs."
-  ;; Simply add a 20% overhead.
-  (round (* 1.2 (closure-size graphs))))
+  ;; Simply add a 25% overhead.
+  (round (* 1.25 (closure-size graphs))))
 
 (define* (initialize-partition-table device partitions
                                      #:key
-- 
2.13.1






reply via email to

[Prev in Thread] Current Thread [Next in Thread]